@@ -1,6 +1,6 @@
 use std::{
     cell::{Cell, RefCell},
-    mem,
+    fmt, mem,
     rc::{Rc, Weak},
 };
 
@@ -51,5 +51,14 @@ impl Drop for Node {
     }
 }
 
+impl fmt::Debug for Node {
+    fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
+        fmt.debug_struct("Node")
+            .field("data", &self.data)
+            .field("children", &self.children)
+            .finish()
+    }
+}
+
 pub type RcNode = Rc<Node>;
 type WeakNode = Weak<Node>;
